use strict;

package Win32::App::which;
our $VERSION = '0.01';

1;

=head1 NAME

Win32::App::which - The 'which' Unix classic command for Windows

=head1 SYNOPSIS

See L<which>.

=head1 AUTHOR

Olivier MenguE<eacute> <dolmen@cpan.org>.

=head1 LICENSE

Same as Perl 5.

=cut
